==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/hu.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Használati és statisztikai adatok",
    "An error occurred while sending your report." : "Hiba történt a jelentés elküldése közben.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Alkalmazás lista <em>(minden appnak: név, verzió, engedélyezési állapot)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Adatbázis környezet <em>(típus, verzió, adatbázis méret)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Titkosítási információk <em>(engedélyezve?, melyik az alapértelmezett modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Megosztások száma <em>(típus és engedély beállítása szerint)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP környezet <em>(verzió, memória korlát, max. végrehajtási idő, max. fájlméret)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szerver telepítés részletek <em>(verzió, memcache használat, zárolási állapot/előnézetek/avatarok)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statisztikai <em>(Számadatok a következőkről: fájlok, felhasználók, tárhelyek típusonként, megjegyzések és címkék szerint)</em>",
    "Help improve Nextcloud" : "Segíts jobbá tenni a Nextcloudot",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Szeretnél segíteni nekünk, hogy javítsuk a Nextcloud-ot? Névtelen statisztikai adatok küldésével megteheted! Amennyiben utólag meggondolod magad bármikor letilthatod az adminisztrárori beállításokban.",
    "Not now" : "Most nem",
    "Send usage" : "Statisztikai adatok küldése",
    "Never" : "Soha",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Segíthet nekünk a Nextcloud javításában, ha elküldi számunkra az aktuális beállításokról és felhasználásokról szóló adatokat.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Komolyan vesszük a magánéletet. Az adatok névtelenek, és bármikor engedélyezheted vagy letilthatod a statisztikai jelentések küldését, alapértelmezetten tiltva van. Az alábbiakban megadhatod, hogy milyen statisztikai adatokat szeretnél elküldeni. Amikor a szerver új jelentést kap, az előző jelentések összes bejegyzése eltávolításra kerül. Ha letiltja az alábbi beállításokat, új jelentést küldhet, amely törli a szerveren jelenleg tárolt jelentéseket.",
    "Send new report now" : "Statisztikai adatok küldése most",
    "Send usage survey monthly" : "Statisztikai adatok küldése havonta",
    "Data to send" : "Küldeni kívánt adatok",
    "Last report" : "Utolsó jelentés",
    "Sent on: {on}" : "Küldés időpontja: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Alkalmazás lista <em>(az egyes alkalmazások: neve, verziószáma, engedélyezve?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "A kiszolgáló adatai <em>(verzió, memcache használat, zárás/előnézet/avatárok engedélyezve?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Segíthet nekünk a Nextcloud javításában, ha elküldi számunkra az aktuális beállításokról és felhasználásokról szóló adatokat.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Komolyan vesszük a magánéletet. Az adatok névtelenek, és bármikor engedélyezheted vagy letilthatod a statisztikai jelentések küldését, alapértelmezetten tiltva van. Az alábbiakban megadhatod, hogy milyen statisztikai adatokat szeretnél elküldeni. Amikor a szerver új jelentést kap, az előző jelentések összes bejegyzése eltávolításra kerül. Ha letiltja az alábbi beállításokat, új jelentést küldhet, amely törli a szerveren jelenleg tárolt jelentéseket.",
    "Sent on: %s" : "Küldés időpontja: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/hu.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Használati és statisztikai adatok",
    "Last report sent on: {on}" : "Utolsó riport megtekintése: {on}",
    "An error occurred while sending your report." : "Hiba történt a jelentés elküldése közben.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Alkalmazás lista <em>(minden appnak: név, verzió, engedélyezési állapot)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Adatbázis környezet <em>(típus, verzió, adatbázis méret)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Titkosítási információk <em>(engedélyezve?, melyik az alapértelmezett modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Megosztások száma <em>(típus és engedély beállítása szerint)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP környezet <em>(verzió, memória korlát, max. végrehajtási idő, max. fájlméret)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szerver telepítés részletek <em>(verzió, memcache használat, zárolási állapot/előnézetek/avatarok)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statisztikai <em>(fájlok, felhasználók, típusonkénti tárhelyek, megjegyzések és címkék szerinti összegzés)</em>",
    "Help improve Nextcloud" : "Segíts jobbá tenni a Nextcloudot",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Szeretnél segíteni nekünk, hogy javítsuk a Nextcloud-ot? Névtelen statisztikai adatok küldésével megteheted! Amennyiben utólag meggondolod magad bármikor letilthatod a rendszergazdai beállításokban.",
    "Not now" : "Most nem",
    "Send usage" : "Statisztikai adatok küldése",
    "Never" : "Soha",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Aninimizált adatok küldése a Nextcloudnak segítve a Nextcloud jobbá tételét.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Segíthet nekünk a Nextcloud javításában, ha elküldi számunkra az aktuális beállításokról és felhasználásokról szóló adatokat.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Komolyan vesszük a magánéletet. Az adatok névtelenek, és bármikor engedélyezheted vagy letilthatod a statisztikai jelentések küldését, alapértelmezetten tiltva van. Az alábbiakban megadhatod, hogy milyen statisztikai adatokat szeretnél elküldeni. Amikor a szerver új jelentést kap, az előző jelentések összes bejegyzése eltávolításra kerül. Ha letiltja az alábbi beállításokat, új jelentést küldhet, amely törli a szerveren jelenleg tárolt jelentéseket.",
    "Send new report now" : "Statisztikai adatok küldése most",
    "Send usage survey monthly" : "Statisztikai adatok küldése havonta",
    "Data to send" : "Küldeni kívánt adatok",
    "Last report sent on: %s" : "Utolsó riport megtekintése: %s",
    "Last report" : "Utolsó jelentés",
    "Sent on: {on}" : "Küldés időpontja: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Alkalmazás lista <em>(az egyes alkalmazások: neve, verziószáma, engedélyezve?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "A kiszolgáló adatai <em>(verzió, memcache használat, zárás/előnézet/avatárok engedélyezve?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statisztikai <em>(Számadatok a következőkről: fájlok, felhasználók, tárhelyek típusonként, megjegyzések és címkék szerint)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Segíthet nekünk a Nextcloud javításában, ha elküldi számunkra az aktuális beállításokról és felhasználásokról szóló adatokat.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Komolyan vesszük a magánéletet. Az adatok névtelenek, és bármikor engedélyezheted vagy letilthatod a statisztikai jelentések küldését, alapértelmezetten tiltva van. Az alábbiakban megadhatod, hogy milyen statisztikai adatokat szeretnél elküldeni. Amikor a szerver új jelentést kap, az előző jelentések összes bejegyzése eltávolításra kerül. Ha letiltja az alábbi beállításokat, új jelentést küldhet, amely törli a szerveren jelenleg tárolt jelentéseket.",
    "Sent on: %s" : "Küldés időpontja: %s"
},
"nplurals=2; plural=(n != 1);");
